# gnatwriter
A novel, short story, or serial writing application. This project is a work in progress. 

More documentation can be found in [this project's wiki](https://github.com/applebiter/gnatwriter/wiki/Introduction-to-GnatWriter).

## Installation

To install, use `pip install gnatwriter`.